@@ -118,9 +118,12 @@ def find_driver(data, driver):
     It filters the drivers available in the date, finding the right one displays statistics.
     If the driver's name was entered incorrectly, an error appears NameError.
     """
-    filterated_date = list(filter(lambda item: item[0] == driver, data))
+    filterated_date = list(filter(lambda item: item[0] == driver, data)) \
+                      or list(filter(lambda item: str("".join(e[0]
+                      for e in str(item[0]).split()) + "".join(e[0]
+                      for e in str(item[1]).split()))[0:3] == driver, data))
     if not filterated_date:
-        raise NameError("Please, check the name of the pilot, enter a valid name. Example 'Sebastian Vettel' ")
+        raise NameError("Please, check the name of the pilot, enter a valid name. Example 'Sebastian Vettel' or 'SVF' ")
     return filterated_date[0]
 
 
